﻿using ASPNETCORE1.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace ASPNETCORE1.Services
{
    public interface IRestauranData
    {
        IEnumerable<Restaurant> GetAll();
        Restaurant Get(int id);
        void Add(Restaurant newRestaurant);
        int Commit();
    }


    public class SqlRestaurantData : IRestauranData
    {
        private RestaurantManagementDbContext _context;

        public SqlRestaurantData(RestaurantManagementDbContext context)
        {
            _context = context;
        }

        public int Commit()
        {
            return _context.SaveChanges();
        }
        public void Add(Restaurant newRestaurant)
        {
            _context.Add(newRestaurant);
            //_context.SaveChanges();
        }

        public Restaurant Get(int id)
        {
            return _context.Restaurants.FirstOrDefault(r => r.Id == id);
        }

        public IEnumerable<Restaurant> GetAll()
        {
            return _context.Restaurants.ToList();
        }
    }


    public class InMemoryRestaurantData : IRestauranData
    {

        public int Commit()
        {
            return 0;
        }
        public void Add(Restaurant newRestaurant)
        {
            newRestaurant.Id = _restaurant.Max(r => r.Id) + 1;
            _restaurant.Add(newRestaurant);
        }

        static InMemoryRestaurantData()
        {
            _restaurant = new List<Restaurant>
            {
                new Restaurant { Id=1,Name="ilia" },
                new Restaurant { Id=2,Name="IranPizza" },
                 new Restaurant{ Id=3,Name="GrandFather" }
            };
        }

        public Restaurant Get(int id)
        {
           return _restaurant.FirstOrDefault(r => r.Id == id);
        }
        public IEnumerable<Restaurant> GetAll()
        {
            return _restaurant;
        }
         static List<Restaurant> _restaurant;
    }
}
